==> haskell-optics-extra-0.4-36-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-optics-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 optics-extra
version:              0.4
visibility:           public
id:                   optics-extra-0.4-Dg6TvgdGPc6J0oHvFWt0Hk
key:                  optics-extra-0.4-Dg6TvgdGPc6J0oHvFWt0Hk
license:              BSD-3-Clause
maintainer:           optics@well-typed.com
author:               Andrzej Rybczak
synopsis:             Extra utilities and instances for optics-core
description:
    This package provides extra definitions and instances that extend the
    @<https://hackage.haskell.org/package/optics-core optics-core>@ package,
    without incurring too many dependencies.  See the
    @<https://hackage.haskell.org/package/optics optics>@ package for more
    documentation.

category:             Data, Optics, Lenses
abi:                  46ae1da0a0dcb03710f1a51a1d6ccb48
exposed:              True
exposed-modules:
    Data.ByteString.Lazy.Optics Data.ByteString.Optics
    Data.ByteString.Strict.Optics Data.HashMap.Optics
    Data.HashSet.Optics Data.Text.Lazy.Optics Data.Text.Optics
    Data.Text.Strict.Optics Data.Vector.Generic.Optics
    Data.Vector.Optics Optics.At Optics.Cons Optics.Each Optics.Empty
    Optics.Extra Optics.Extra.Internal.ByteString
    Optics.Extra.Internal.Vector Optics.Extra.Internal.Zoom
    Optics.Indexed Optics.Passthrough Optics.State
    Optics.State.Operators Optics.View Optics.Zoom

import-dirs:          /usr/lib/ghc-9.0.1/site-local/optics-extra-0.4
library-dirs:         /usr/lib/ghc-9.0.1/site-local/optics-extra-0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/optics-extra-0.4
hs-libraries:         HSoptics-extra-0.4-Dg6TvgdGPc6J0oHvFWt0Hk
depends:
    array-0.5.4.0 base-4.15.0.0 bytestring-0.10.12.1 containers-0.6.4.1
    hashable-1.3.2.0-2579b4ed8EpGiVuNwiQjKE
    indexed-profunctors-0.1.1-GQTIGxqDJ6jFqxn3qvYbGz
    indexed-traversable-instances-0.1-JLRg5Kqea4FAY67q5Z6KtT mtl-2.2.2
    optics-core-0.4-93Dqg26YwQUDlxX9SGGdaY text-1.2.4.1
    transformers-0.5.6.2
    unordered-containers-0.2.14.0-4DhuFzG9cx0DMeOsWontjN
    vector-0.12.3.0-EgyyrXPknFmH9St10tSSKB

haddock-interfaces:
    /usr/share/doc/haskell-optics-extra/html/optics-extra.haddock

haddock-html:         /usr/share/doc/haskell-optics-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-optics-extra-0.4-38-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-optics-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 optics-extra
version:              0.4
visibility:           public
id:                   optics-extra-0.4-HQeclKRDaYoAKBbqRTEtlV
key:                  optics-extra-0.4-HQeclKRDaYoAKBbqRTEtlV
license:              BSD-3-Clause
maintainer:           optics@well-typed.com
author:               Andrzej Rybczak
synopsis:             Extra utilities and instances for optics-core
description:
    This package provides extra definitions and instances that extend the
    @<https://hackage.haskell.org/package/optics-core optics-core>@ package,
    without incurring too many dependencies.  See the
    @<https://hackage.haskell.org/package/optics optics>@ package for more
    documentation.

category:             Data, Optics, Lenses
abi:                  00209a3592d9b06150381a026f6c3d3e
exposed:              True
exposed-modules:
    Data.ByteString.Lazy.Optics Data.ByteString.Optics
    Data.ByteString.Strict.Optics Data.HashMap.Optics
    Data.HashSet.Optics Data.Text.Lazy.Optics Data.Text.Optics
    Data.Text.Strict.Optics Data.Vector.Generic.Optics
    Data.Vector.Optics Optics.At Optics.Cons Optics.Each Optics.Empty
    Optics.Extra Optics.Extra.Internal.ByteString
    Optics.Extra.Internal.Vector Optics.Extra.Internal.Zoom
    Optics.Indexed Optics.Passthrough Optics.State
    Optics.State.Operators Optics.View Optics.Zoom

import-dirs:          /usr/lib/ghc-9.0.1/site-local/optics-extra-0.4
library-dirs:         /usr/lib/ghc-9.0.1/site-local/optics-extra-0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/optics-extra-0.4
hs-libraries:         HSoptics-extra-0.4-HQeclKRDaYoAKBbqRTEtlV
depends:
    array-0.5.4.0 base-4.15.0.0 bytestring-0.10.12.1 containers-0.6.4.1
    hashable-1.3.3.0-BjQXPnRjTz0I5yXUcLzcAY
    indexed-profunctors-0.1.1-GQTIGxqDJ6jFqxn3qvYbGz
    indexed-traversable-instances-0.1-Dk24cHEcagmEVtErpbaGHi mtl-2.2.2
    optics-core-0.4-93Dqg26YwQUDlxX9SGGdaY text-1.2.4.1
    transformers-0.5.6.2
    unordered-containers-0.2.14.0-DBDZ3ZaaKWNDxQAlLFMrPR
    vector-0.12.3.0-7AyAfn90uRLJwvulX46pQG

haddock-interfaces:
    /usr/share/doc/haskell-optics-extra/html/optics-extra.haddock

haddock-html:         /usr/share/doc/haskell-optics-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
